@@ -59,7 +59,7 @@ def div(x, y):
 
 def load_dffromCsv(dfname):
     dir='/dbfs/user/hive/warehouse/'
-    df=dh.pd.read_csv(dir+dfname)
+    df=pd.read_csv(dir+dfname)
     print(dfname, 'loaded!')
     return df
 
